@@ -91,7 +91,7 @@ typedef struct feedcontext {
 
 static long long  datetounix(long long, int, int, int, int, int);
 static enum TagId gettag(enum FeedType, const char *, size_t);
-static long long  gettzoffset(const char *);
+static long gettzoffset(const char *);
 static int  isattr(const char *, size_t, const char *, size_t);
 static int  istag(const char *, size_t, const char *, size_t);
 static int  parsetime(const char *, time_t *);
@@ -105,6 +105,8 @@ static void string_print_trimmed(String *);
 static void string_print_uri(String *);
 static void xmlattr(XMLParser *, const char *, size_t, const char *, size_t,
                     const char *, size_t);
+static void xmlattrentity(XMLParser *, const char *, size_t, const char *,
+                          size_t, const char *, size_t);
 static void xmlattrend(XMLParser *, const char *, size_t, const char *,
                        size_t);
 static void xmlattrstart(XMLParser *, const char *, size_t, const char *,
@@ -248,8 +250,12 @@ string_buffer_realloc(String *s, size_t newlen)
 {
 	size_t alloclen;
 
-	for (alloclen = 64; alloclen <= newlen; alloclen *= 2)
-		;
+	if (newlen > SIZE_MAX / 2) {
+		alloclen = SIZE_MAX;
+	} else {
+		for (alloclen = 64; alloclen <= newlen; alloclen *= 2)
+			;
+	}
 	if (!(s->data = realloc(s->data, alloclen)))
 		err(1, "realloc");
 	s->bufsiz = alloclen;
@@ -260,8 +266,14 @@ string_append(String *s, const char *data, size_t len)
 {
 	if (!len)
 		return;
-	/* check if allocation is necesary, don't shrink buffer,
-	 * should be more than bufsiz ofcourse. */
+
+	if (s->len >= SIZE_MAX - len) {
+		errno = EOVERFLOW;
+		err(1, "realloc");
+	}
+
+	/* check if allocation is necessary, don't shrink buffer,
+	 * should be more than bufsiz of course. */
 	if (s->len + len >= s->bufsiz)
 		string_buffer_realloc(s, s->len + len + 1);
 	memcpy(s->data + s->len, data, len);
@@ -410,7 +422,7 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
  * ambiguous anyway.
  * ANSI and military zones are defined wrong in RFC822 and are unsupported,
  * see note on RFC2822 4.3 page 32. */
-static long long
+static long
 gettzoffset(const char *s)
 {
 	static struct {
@@ -427,7 +439,7 @@ gettzoffset(const char *s)
 		{ "PST", -8 * 3600 },
 	};
 	const char *p;
-	int tzhour = 0, tzmin = 0;
+	long tzhour = 0, tzmin = 0;
 	size_t i;
 
 	for (; *s && isspace((unsigned char)*s); s++)
@@ -607,7 +619,7 @@ xmlattr(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
 		return;
 	}
 
-	if (ctx.feedtype == FeedTypeNone)
+	if (!ctx.tagid)
 		return;
 
 	/* content-type may be: Atom: text, xhtml, html or mime-type.
@@ -655,6 +667,31 @@ xmlattr(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
 	}
 }
 
+static void
+xmlattrentity(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
+              const char *data, size_t datalen)
+{
+	char buf[16];
+	ssize_t len;
+
+	/* handles transforming inline XML to data */
+	if (ISINCONTENT(ctx)) {
+		if (ctx.contenttype == ContentTypeHTML)
+			xmldata(p, data, datalen);
+		return;
+	}
+
+	if (!ctx.tagid)
+		return;
+
+	/* try to translate entity, else just pass as data to
+	 * xmldata handler. */
+	if ((len = xml_entitytostr(data, buf, sizeof(buf))) > 0)
+		xmlattr(p, t, tl, n, nl, buf, (size_t)len);
+	else
+		xmlattr(p, t, tl, n, nl, data, datalen);
+}
+
 static void
 xmlattrend(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl)
 {
@@ -713,7 +750,7 @@ xmldataentity(XMLParser *p, const char *data, size_t datalen)
 		return;
 
 	/* try to translate entity, else just pass as data to
-	 * xml_data_handler. */
+	 * xmldata handler. */
 	if ((len = xml_entitytostr(data, buf, sizeof(buf))) > 0)
 		xmldata(p, buf, (size_t)len);
 	else
@@ -881,6 +918,7 @@ main(int argc, char *argv[])
 		baseurl = argv[1];
 
 	parser.xmlattr = xmlattr;
+	parser.xmlattrentity = xmlattrentity;
 	parser.xmlattrend = xmlattrend;
 	parser.xmlattrstart = xmlattrstart;
 	parser.xmlcdata = xmlcdata;
